@@ -52,6 +52,28 @@ def crush_cg_crush_void_tumor(root='/data/ldap/histopathologic/original_read_onl
     return Crush(root, class_to_idx, tissue='CG', zoom=zoom, transform=transform, target_transform=target_transform, scale=scale)
 
 
+def crush_cm_crush_void_tumor(root='/data/ldap/histopathologic/original_read_only/Crush/Patches', zoom: int = 0, transform: Optional[Callable] = None, target_transform: Optional[Callable] = None, scale: bool = False):
+    # Filter function
+    class_to_idx = {
+        "Crush": 0,
+        "Crush-void": 0,
+        "Tumor": 1
+    }
+
+    return Crush(root, class_to_idx, tissue='CM', zoom=zoom, transform=transform, target_transform=target_transform, scale=scale)
+
+
+def crush_crush_void_tumor(root='/data/ldap/histopathologic/original_read_only/Crush/Patches', zoom: int = 0, transform: Optional[Callable] = None, target_transform: Optional[Callable] = None, scale: bool = False):
+    # Filter function
+    class_to_idx = {
+        "Crush": 0,
+        "Crush-void": 0,
+        "Tumor": 1
+    }
+
+    return Crush(root, class_to_idx, tissue='CM', zoom=zoom, transform=transform, target_transform=target_transform, scale=scale)
+
+
 class Crush96x96(H5Dataset):
     """
     Data and further information can be found at TODO
